Gating Mechanism
================

.. automodule:: psyneulink.core.components.mechanisms.modulatory.gating.gatingmechanism
   :members:
   :private-members:
   :exclude-members: Linear, random, Parameters
